# beaucli
a tool for making your cli applications way more colorful!

# status
- ![pip](https://github.com/memesterhub/beaucli/workflows/Upload%20Python%20Package/badge.svg)

# installation
by pip
```sh
pip install beaucli
```
from source code
```sh
git clone https://github/com/memesterhub/beaucli
python setup.py install
```
# Description
basically beaucli is a tool for making your command line applications better by providing you colors and some extra tools

# Introduction
```py
import beaucli
print(beaucli.fore("Hello In Red!", "red"))
```

# [Documentation](https://husseinraed.cf/beaucli/)
